"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.entry import Entry
from cvg_sdk.model.external_call_id import ExternalCallId
globals()['Entry'] = Entry
globals()['ExternalCallId'] = ExternalCallId
from cvg_sdk.model.dialog import Dialog


class TestDialog(unittest.TestCase):
    """Dialog unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDialog(self):
        """Test Dialog"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Dialog()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Call API

    With the VIER Cognitive Voice Call API you can easily do things like building your voicebots, which can be reached via phone calls. You can receive speech input of the customer as transcripted text in many languages. Let different voices say your text in this call. After the voicebot dialog you may drop the call (call fully completed by bot) or transfer the call e.g. to the relevant service hotline (human agent required to satisfy customer).  On some events, such as receiving an incoming phone call or transcription of a customer's utterance, VIER makes an HTTP request to a URL to be provided by you. This is called a webhook. To handle a webhook, you need to build a small web application that can accept the HTTP requests. The required webhooks are listed as bot endpoints.  The operations defined in this specification can be used by your bot to trigger certain voice and/or telephony related actions on the currently active call.  Most of the available operations are subject to queuing, meaning that the commands, even when triggered simultaneously, will not be executed simultaneously. Instead, these operations will be executed after each other. This is being done to simplify bot development as otherwise the bot would need to hit exact timings for the operations it triggers to not produce overlapping audio in the phone and still be quick enough to feel responsive to the conversation partner.  The queuing mechanism allows the bot to simply trigger several operations after each other and CVG makes sure to to execute them without overlap after each other. Some operations also support a `bargeIn` flag, which makes the operation interruptible by the conversation partner.  All operations that are not subject to queuing will document this fact in their respective description.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cvg_sdk.api_client import ApiClient, Endpoint as _Endpoint
from cvg_sdk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cvg_sdk.model.bridge_parameters import BridgeParameters
from cvg_sdk.model.data_parameters import DataParameters
from cvg_sdk.model.dial_parameters import DialParameters
from cvg_sdk.model.drop_parameters import DropParameters
from cvg_sdk.model.forward_parameters import ForwardParameters
from cvg_sdk.model.inactivity_start_parameters import InactivityStartParameters
from cvg_sdk.model.inactivity_stop_parameters import InactivityStopParameters
from cvg_sdk.model.outbound_call_result import OutboundCallResult
from cvg_sdk.model.play_parameters import PlayParameters
from cvg_sdk.model.prompt_parameters import PromptParameters
from cvg_sdk.model.recording_start_parameters import RecordingStartParameters
from cvg_sdk.model.recording_stop_parameters import RecordingStopParameters
from cvg_sdk.model.say_parameters import SayParameters
from cvg_sdk.model.transcription_switch_parameters import TranscriptionSwitchParameters


class CallApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.bridge_endpoint = _Endpoint(
            settings={
                'response_type': (OutboundCallResult,),
                'auth': [],
                'endpoint_path': '/call/bridge',
                'operation_id': 'bridge',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'bridge_parameters',
                ],
                'required': [
                    'bridge_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'bridge_parameters':
                        (BridgeParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'bridge_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.data_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/data',
                'operation_id': 'data',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'data_parameters',
                ],
                'required': [
                    'data_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'data_parameters':
                        (DataParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'data_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.dial_endpoint = _Endpoint(
            settings={
                'response_type': (OutboundCallResult,),
                'auth': [],
                'endpoint_path': '/call/dial',
                'operation_id': 'dial',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'dial_parameters',
                ],
                'required': [
                    'dial_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dial_parameters':
                        (DialParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'dial_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.drop_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/drop',
                'operation_id': 'drop',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'drop_parameters',
                ],
                'required': [
                    'drop_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'drop_parameters':
                        (DropParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'drop_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.forward_endpoint = _Endpoint(
            settings={
                'response_type': (OutboundCallResult,),
                'auth': [],
                'endpoint_path': '/call/forward',
                'operation_id': 'forward',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'forward_parameters',
                ],
                'required': [
                    'forward_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'forward_parameters':
                        (ForwardParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'forward_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.play_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/play',
                'operation_id': 'play',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'play_parameters',
                ],
                'required': [
                    'play_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'play_parameters':
                        (PlayParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'play_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.prompt_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/prompt',
                'operation_id': 'prompt',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'prompt_parameters',
                ],
                'required': [
                    'prompt_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'prompt_parameters':
                        (PromptParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'prompt_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.say_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/say',
                'operation_id': 'say',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'say_parameters',
                ],
                'required': [
                    'say_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'say_parameters':
                        (SayParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'say_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_inactivity_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/inactivity/start',
                'operation_id': 'start_inactivity',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'inactivity_start_parameters',
                ],
                'required': [
                    'inactivity_start_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'inactivity_start_parameters':
                        (InactivityStartParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'inactivity_start_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_recording_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/recording/start',
                'operation_id': 'start_recording',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'recording_start_parameters',
                ],
                'required': [
                    'recording_start_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'recording_start_parameters':
                        (RecordingStartParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'recording_start_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.stop_inactivity_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/inactivity/stop',
                'operation_id': 'stop_inactivity',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'inactivity_stop_parameters',
                ],
                'required': [
                    'inactivity_stop_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'inactivity_stop_parameters':
                        (InactivityStopParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'inactivity_stop_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.stop_recording_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/recording/stop',
                'operation_id': 'stop_recording',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'recording_stop_parameters',
                ],
                'required': [
                    'recording_stop_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'recording_stop_parameters':
                        (RecordingStopParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'recording_stop_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.switch_transcription_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/call/transcription/switch',
                'operation_id': 'switch_transcription',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'transcription_switch_parameters',
                ],
                'required': [
                    'transcription_switch_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'transcription_switch_parameters':
                        (TranscriptionSwitchParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'transcription_switch_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def bridge(
        self,
        bridge_parameters,
        **kwargs
    ):
        """Bridge the call to a different destination for agent assistance  # noqa: E501

        Bridge the call to a different destination for the agent assistance use case.  This request is blocking, i.e. the response will be held until the call has either been accepted or rejected. Make sure HTTP client read timeouts are configured accordingly for requests to this endpoint.  The called number is constructed by appending a random n-digit number to `headNumber` (where n is `extensionLength`). The number is then reserved until the Assist API's `/assist/accept` endpoint is called, which frees the number again. If this doesn't happen within 130 seconds, the allocation times out.  After a successful bridge, the bot is now out of the loop and will neither receive further messages nor can send any commands. If the call is being recorded, the recording will also be stopped automatically.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bridge(bridge_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            bridge_parameters (BridgeParameters): Parameters for the bridge operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OutboundCallResult
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['bridge_parameters'] = \
            bridge_parameters
        return self.bridge_endpoint.call_with_http_info(**kwargs)

    def data(
        self,
        data_parameters,
        **kwargs
    ):
        """Deprecated, use the `/dialog/{resellerToken}/{dialogId}/data` endpoint instead.  # noqa: E501

        Deprecated, use the `/dialog/{resellerToken}/{dialogId}/data` endpoint instead. This operation is not subject to queuing.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.data(data_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            data_parameters (DataParameters): Parameters for the data operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['data_parameters'] = \
            data_parameters
        return self.data_endpoint.call_with_http_info(**kwargs)

    def dial(
        self,
        dial_parameters,
        **kwargs
    ):
        """Begin a call to an external number  # noqa: E501

        Begin a call to an external number.  This request is blocking, i.e. the response will be held until the call has either been accepted or rejected. Make sure HTTP client read timeouts are configured accordingly for requests to this endpoint.  Due to limitations imposed by the telephony infrastructure, the amount of concurrent outbound calls is rate limited. Since the exact amount of possible concurrent calls depends on many technical and organizational details, the platform does not provide any details on how many calls per unit time can be done, it just informs the client application if a rate limitation was hit. The application driving outbound calls is expected to handle this scenario by applying common retry techniques like e.g. binary exponential backoff.  This operation is not subject to queuing since it happens before a call has been established.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.dial(dial_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            dial_parameters (DialParameters): Parameters for the dial operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OutboundCallResult
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['dial_parameters'] = \
            dial_parameters
        return self.dial_endpoint.call_with_http_info(**kwargs)

    def drop(
        self,
        drop_parameters,
        **kwargs
    ):
        """Drop the call  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.drop(drop_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            drop_parameters (DropParameters): Parameters for the drop operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['drop_parameters'] = \
            drop_parameters
        return self.drop_endpoint.call_with_http_info(**kwargs)

    def forward(
        self,
        forward_parameters,
        **kwargs
    ):
        """Forward the call to a different destination  # noqa: E501

        Forward the call to a different destination.  This request is blocking, i.e. the response will be held until the call has either been accepted or rejected. Make sure HTTP client read timeouts are configured accordingly for requests to this endpoint.  After a successful forward, the bot is now out of the loop and will neither receive further messages nor can send any commands. If the call is being recorded, the recording will also be stopped automatically.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.forward(forward_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            forward_parameters (ForwardParameters): Parameters for the forward operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            OutboundCallResult
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['forward_parameters'] = \
            forward_parameters
        return self.forward_endpoint.call_with_http_info(**kwargs)

    def play(
        self,
        play_parameters,
        **kwargs
    ):
        """Play something to the call  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.play(play_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            play_parameters (PlayParameters): Parameters for the play operation.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['play_parameters'] = \
            play_parameters
        return self.play_endpoint.call_with_http_info(**kwargs)

    def prompt(
        self,
        prompt_parameters,
        **kwargs
    ):
        """Say something to the call with a prompt  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.prompt(prompt_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            prompt_parameters (PromptParameters): Prompts are a convenient way to ask for different types of user input. While a prompt is active, the dialog behaves slightly differently than usual:  - No `type = DTMF` events are sent to the Bot API's `/message` endpoint.   `type = SPEECH` events still make it to the bot as long as they don't match one of the `MultipleChoice`   prompt choices. Since `Number` prompts don't accept voice input, they don't block any speech events. - No `/inactivity` events are sent to the bot, since the prompt's own timeout takes precedence over the   inactivity timeout configured in the project settings.  There's three ways a prompt can end:  - A Bot API `/answer` event with type `Timeout` if the prompt timeout has expired. - A Bot API `/answer` event with type `MultipleChoice` or `Number` if one of the stop conditions is met. - `/call/prompt` is called again, which effectively cancels the previously active prompt.   This also discards any input that was already aggregated.  The prompt timeout restarts on user input (transcription results or DTMF).

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['prompt_parameters'] = \
            prompt_parameters
        return self.prompt_endpoint.call_with_http_info(**kwargs)

    def say(
        self,
        say_parameters,
        **kwargs
    ):
        """Say something to the call  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.say(say_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            say_parameters (SayParameters): Parameters for the say operation. Use SSML tags to customize and control aspects of speech such as pronunciation, volume, and speech rate. When using SSML enclose the entire text in a `<speak>` tag.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['say_parameters'] = \
            say_parameters
        return self.say_endpoint.call_with_http_info(**kwargs)

    def start_inactivity(
        self,
        inactivity_start_parameters,
        **kwargs
    ):
        """Start inactivity detection  # noqa: E501

        Start inactivity detection with a specified timeout.  The automatic inactivity timeout in the project settings must be disabled for this endpoint to be available.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_inactivity(inactivity_start_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            inactivity_start_parameters (InactivityStartParameters): Parameters for the inactivity start operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['inactivity_start_parameters'] = \
            inactivity_start_parameters
        return self.start_inactivity_endpoint.call_with_http_info(**kwargs)

    def start_recording(
        self,
        recording_start_parameters,
        **kwargs
    ):
        """Start or resume recording of the call  # noqa: E501

        Starts or resumes recording of the call.  IMPORTANT: it is the responsibility of the API user to ensure that recording the participants of the call is legal according to the privacy laws and regulations that apply in the respective country.  Recordings can only be made if this has been explicitly allowed in each layer of the hierarchy (reseller, customer, account, project). They are stored for the duration specified in the project settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_recording(recording_start_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            recording_start_parameters (RecordingStartParameters): Parameters for the recording start operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['recording_start_parameters'] = \
            recording_start_parameters
        return self.start_recording_endpoint.call_with_http_info(**kwargs)

    def stop_inactivity(
        self,
        inactivity_stop_parameters,
        **kwargs
    ):
        """Stop inactivity detection  # noqa: E501

        Stop inactivity detection.  The automatic inactivity timeout in the project settings must be disabled for this endpoint to be available.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stop_inactivity(inactivity_stop_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            inactivity_stop_parameters (InactivityStopParameters): Parameters for the inactivity stop operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['inactivity_stop_parameters'] = \
            inactivity_stop_parameters
        return self.stop_inactivity_endpoint.call_with_http_info(**kwargs)

    def stop_recording(
        self,
        recording_stop_parameters,
        **kwargs
    ):
        """Pause or terminate recording of the call  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stop_recording(recording_stop_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            recording_stop_parameters (RecordingStopParameters): Parameters for the recording stop operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['recording_stop_parameters'] = \
            recording_stop_parameters
        return self.stop_recording_endpoint.call_with_http_info(**kwargs)

    def switch_transcription(
        self,
        transcription_switch_parameters,
        **kwargs
    ):
        """Switch transcription vendor/profile and/or language  # noqa: E501

        Switch transcription to a different vendor/profile and/or language.  The `transcribers` and `language` parameters are optional and fall back to the project settings. As a result, you can omit both of them to reset transcription back to the project settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.switch_transcription(transcription_switch_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            transcription_switch_parameters (TranscriptionSwitchParameters): Parameters for the transcription switch operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['transcription_switch_parameters'] = \
            transcription_switch_parameters
        return self.switch_transcription_endpoint.call_with_http_info(**kwargs)




"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.answer_type import AnswerType
from cvg_sdk.model.multiple_choice_answer import MultipleChoiceAnswer
from cvg_sdk.model.number_answer import NumberAnswer
from cvg_sdk.model.timeout_answer import TimeoutAnswer
globals()['AnswerType'] = AnswerType
globals()['MultipleChoiceAnswer'] = MultipleChoiceAnswer
globals()['NumberAnswer'] = NumberAnswer
globals()['TimeoutAnswer'] = TimeoutAnswer
from cvg_sdk.model.timeout_answer import TimeoutAnswer


class TestTimeoutAnswer(unittest.TestCase):
    """TimeoutAnswer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTimeoutAnswer(self):
        """Test TimeoutAnswer"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TimeoutAnswer()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Assist API

    With the CVG Assist API you can use live transcriptions of customers to provide in-call agent assistance.  CVG Assist API requires some integration with contact center software to link ACD phone number, dialogID und agentID. The call has to be bridged to the contact center head number of e.g. a hotline plus an extension. The contact center then has to invoke `/assist/accept` with the phone number.  Integration with VIER Engage is available. Ask us if you are interested in integrating other contact center software.  CVG Assist API is part of the VIER Cognitive Voice Gateway.  For more details, see [our documentation](/docs/Essential-Use-Cases.html#agent-assistance).  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.assist_recording_start_parameters_all_of import AssistRecordingStartParametersAllOf


class TestAssistRecordingStartParametersAllOf(unittest.TestCase):
    """AssistRecordingStartParametersAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAssistRecordingStartParametersAllOf(self):
        """Test AssistRecordingStartParametersAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = AssistRecordingStartParametersAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.confidence import Confidence
globals()['Confidence'] = Confidence
from cvg_sdk.model.voice_all_of import VoiceAllOf


class TestVoiceAllOf(unittest.TestCase):
    """VoiceAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testVoiceAllOf(self):
        """Test VoiceAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = VoiceAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Call API

    With the VIER Cognitive Voice Call API you can easily do things like building your voicebots, which can be reached via phone calls. You can receive speech input of the customer as transcripted text in many languages. Let different voices say your text in this call. After the voicebot dialog you may drop the call (call fully completed by bot) or transfer the call e.g. to the relevant service hotline (human agent required to satisfy customer).  On some events, such as receiving an incoming phone call or transcription of a customer's utterance, VIER makes an HTTP request to a URL to be provided by you. This is called a webhook. To handle a webhook, you need to build a small web application that can accept the HTTP requests. The required webhooks are listed as bot endpoints.  The operations defined in this specification can be used by your bot to trigger certain voice and/or telephony related actions on the currently active call.  Most of the available operations are subject to queuing, meaning that the commands, even when triggered simultaneously, will not be executed simultaneously. Instead, these operations will be executed after each other. This is being done to simplify bot development as otherwise the bot would need to hit exact timings for the operations it triggers to not produce overlapping audio in the phone and still be quick enough to feel responsive to the conversation partner.  The queuing mechanism allows the bot to simply trigger several operations after each other and CVG makes sure to to execute them without overlap after each other. Some operations also support a `bargeIn` flag, which makes the operation interruptible by the conversation partner.  All operations that are not subject to queuing will document this fact in their respective description.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.call_parameters import CallParameters
globals()['CallParameters'] = CallParameters
from cvg_sdk.model.inactivity_stop_parameters import InactivityStopParameters


class TestInactivityStopParameters(unittest.TestCase):
    """InactivityStopParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInactivityStopParameters(self):
        """Test InactivityStopParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = InactivityStopParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Assist API

    With the CVG Assist API you can use live transcriptions of customers to provide in-call agent assistance.  CVG Assist API requires some integration with contact center software to link ACD phone number, dialogID und agentID. The call has to be bridged to the contact center head number of e.g. a hotline plus an extension. The contact center then has to invoke `/assist/accept` with the phone number.  Integration with VIER Engage is available. Ask us if you are interested in integrating other contact center software.  CVG Assist API is part of the VIER Cognitive Voice Gateway.  For more details, see [our documentation](/docs/Essential-Use-Cases.html#agent-assistance).  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.assist_api import AssistApi  # noqa: E501


class TestAssistApi(unittest.TestCase):
    """AssistApi unit test stubs"""

    def setUp(self):
        self.api = AssistApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_assist(self):
        """Test case for accept_assist

        Accept assist  # noqa: E501
        """
        pass

    def test_start_recording(self):
        """Test case for start_recording

        Start or resume recording of the call  # noqa: E501
        """
        pass

    def test_start_transcription(self):
        """Test case for start_transcription

        Start transcription  # noqa: E501
        """
        pass

    def test_stop_recording(self):
        """Test case for stop_recording

        Pause or terminate recording of the call  # noqa: E501
        """
        pass

    def test_stop_transcription(self):
        """Test case for stop_transcription

        Stop transcription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Call API

    With the VIER Cognitive Voice Call API you can easily do things like building your voicebots, which can be reached via phone calls. You can receive speech input of the customer as transcripted text in many languages. Let different voices say your text in this call. After the voicebot dialog you may drop the call (call fully completed by bot) or transfer the call e.g. to the relevant service hotline (human agent required to satisfy customer).  On some events, such as receiving an incoming phone call or transcription of a customer's utterance, VIER makes an HTTP request to a URL to be provided by you. This is called a webhook. To handle a webhook, you need to build a small web application that can accept the HTTP requests. The required webhooks are listed as bot endpoints.  The operations defined in this specification can be used by your bot to trigger certain voice and/or telephony related actions on the currently active call.  Most of the available operations are subject to queuing, meaning that the commands, even when triggered simultaneously, will not be executed simultaneously. Instead, these operations will be executed after each other. This is being done to simplify bot development as otherwise the bot would need to hit exact timings for the operations it triggers to not produce overlapping audio in the phone and still be quick enough to feel responsive to the conversation partner.  The queuing mechanism allows the bot to simply trigger several operations after each other and CVG makes sure to to execute them without overlap after each other. Some operations also support a `bargeIn` flag, which makes the operation interruptible by the conversation partner.  All operations that are not subject to queuing will document this fact in their respective description.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.call_api import CallApi  # noqa: E501


class TestCallApi(unittest.TestCase):
    """CallApi unit test stubs"""

    def setUp(self):
        self.api = CallApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_bridge(self):
        """Test case for bridge

        Bridge the call to a different destination for agent assistance  # noqa: E501
        """
        pass

    def test_data(self):
        """Test case for data

        Deprecated, use the `/dialog/{resellerToken}/{dialogId}/data` endpoint instead.  # noqa: E501
        """
        pass

    def test_dial(self):
        """Test case for dial

        Begin a call to an external number  # noqa: E501
        """
        pass

    def test_drop(self):
        """Test case for drop

        Drop the call  # noqa: E501
        """
        pass

    def test_forward(self):
        """Test case for forward

        Forward the call to a different destination  # noqa: E501
        """
        pass

    def test_play(self):
        """Test case for play

        Play something to the call  # noqa: E501
        """
        pass

    def test_prompt(self):
        """Test case for prompt

        Say something to the call with a prompt  # noqa: E501
        """
        pass

    def test_say(self):
        """Test case for say

        Say something to the call  # noqa: E501
        """
        pass

    def test_start_inactivity(self):
        """Test case for start_inactivity

        Start inactivity detection  # noqa: E501
        """
        pass

    def test_start_recording(self):
        """Test case for start_recording

        Start or resume recording of the call  # noqa: E501
        """
        pass

    def test_stop_inactivity(self):
        """Test case for stop_inactivity

        Stop inactivity detection  # noqa: E501
        """
        pass

    def test_stop_recording(self):
        """Test case for stop_recording

        Pause or terminate recording of the call  # noqa: E501
        """
        pass

    def test_switch_transcription(self):
        """Test case for switch_transcription

        Switch transcription vendor/profile and/or language  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.dialog_api import DialogApi  # noqa: E501


class TestDialogApi(unittest.TestCase):
    """DialogApi unit test stubs"""

    def setUp(self):
        self.api = DialogApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_custom_data(self):
        """Test case for attach_custom_data

        Attach custom data to a dialog  # noqa: E501
        """
        pass

    def test_delete_dialog(self):
        """Test case for delete_dialog

        Delete dialog by dialog ID  # noqa: E501
        """
        pass

    def test_get_dialog(self):
        """Test case for get_dialog

        Get dialog by dialog ID  # noqa: E501
        """
        pass

    def test_get_dialog_by_external_call_id(self):
        """Test case for get_dialog_by_external_call_id

        Get dialog by external call ID  # noqa: E501
        """
        pass

    def test_get_single_entry(self):
        """Test case for get_single_entry

        Get a single custom dialog data entry  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.recording_id import RecordingId
globals()['RecordingId'] = RecordingId
from cvg_sdk.model.recording_start_all_of import RecordingStartAllOf


class TestRecordingStartAllOf(unittest.TestCase):
    """RecordingStartAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testRecordingStartAllOf(self):
        """Test RecordingStartAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = RecordingStartAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.aggregated_latencies import AggregatedLatencies
from cvg_sdk.model.audio_playback_failed import AudioPlaybackFailed
from cvg_sdk.model.endpoint_call import EndpointCall
from cvg_sdk.model.endpoint_call_all_of import EndpointCallAllOf
from cvg_sdk.model.endpoint_call_failed import EndpointCallFailed
from cvg_sdk.model.health_event_status import HealthEventStatus
from cvg_sdk.model.internal_error import InternalError
from cvg_sdk.model.project_health_event import ProjectHealthEvent
from cvg_sdk.model.provisioning_timed_out import ProvisioningTimedOut
from cvg_sdk.model.synthesis import Synthesis
from cvg_sdk.model.synthesis_failed import SynthesisFailed
from cvg_sdk.model.transcription import Transcription
from cvg_sdk.model.transcription_failed import TranscriptionFailed
globals()['AggregatedLatencies'] = AggregatedLatencies
globals()['AudioPlaybackFailed'] = AudioPlaybackFailed
globals()['EndpointCall'] = EndpointCall
globals()['EndpointCallAllOf'] = EndpointCallAllOf
globals()['EndpointCallFailed'] = EndpointCallFailed
globals()['HealthEventStatus'] = HealthEventStatus
globals()['InternalError'] = InternalError
globals()['ProjectHealthEvent'] = ProjectHealthEvent
globals()['ProvisioningTimedOut'] = ProvisioningTimedOut
globals()['Synthesis'] = Synthesis
globals()['SynthesisFailed'] = SynthesisFailed
globals()['Transcription'] = Transcription
globals()['TranscriptionFailed'] = TranscriptionFailed
from cvg_sdk.model.endpoint_call import EndpointCall


class TestEndpointCall(unittest.TestCase):
    """EndpointCall unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointCall(self):
        """Test EndpointCall"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointCall()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.language import Language
globals()['Language'] = Language
from cvg_sdk.model.speech_service_configuration import SpeechServiceConfiguration


class TestSpeechServiceConfiguration(unittest.TestCase):
    """SpeechServiceConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSpeechServiceConfiguration(self):
        """Test SpeechServiceConfiguration"""
        # FIXME: construct object with mandatory attributes with example values
        # model = SpeechServiceConfiguration()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.aggregated_latencies import AggregatedLatencies
globals()['AggregatedLatencies'] = AggregatedLatencies
from cvg_sdk.model.endpoint_call_all_of import EndpointCallAllOf


class TestEndpointCallAllOf(unittest.TestCase):
    """EndpointCallAllOf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEndpointCallAllOf(self):
        """Test EndpointCallAllOf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EndpointCallAllOf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from cvg_sdk.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from cvg_sdk.model.aggregated_latencies import AggregatedLatencies
from cvg_sdk.model.audio_playback_failed import AudioPlaybackFailed
from cvg_sdk.model.audio_playback_failed_all_of import AudioPlaybackFailedAllOf
from cvg_sdk.model.endpoint_call import EndpointCall
from cvg_sdk.model.endpoint_call_all_of import EndpointCallAllOf
from cvg_sdk.model.endpoint_call_failed import EndpointCallFailed
from cvg_sdk.model.endpoint_call_failed_all_of import EndpointCallFailedAllOf
from cvg_sdk.model.health_event_status import HealthEventStatus
from cvg_sdk.model.health_status import HealthStatus
from cvg_sdk.model.internal_error import InternalError
from cvg_sdk.model.internal_error_all_of import InternalErrorAllOf
from cvg_sdk.model.language import Language
from cvg_sdk.model.project_health import ProjectHealth
from cvg_sdk.model.project_health_event import ProjectHealthEvent
from cvg_sdk.model.provisioning_timed_out import ProvisioningTimedOut
from cvg_sdk.model.speech_service_configuration import SpeechServiceConfiguration
from cvg_sdk.model.speech_service_failed_properties import SpeechServiceFailedProperties
from cvg_sdk.model.synthesis import Synthesis
from cvg_sdk.model.synthesis_failed import SynthesisFailed
from cvg_sdk.model.time_range import TimeRange
from cvg_sdk.model.transcription import Transcription
from cvg_sdk.model.transcription_all_of import TranscriptionAllOf
from cvg_sdk.model.transcription_failed import TranscriptionFailed



"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.multiple_choice_prompt import MultipleChoicePrompt
from cvg_sdk.model.multiple_choice_prompt_all_of import MultipleChoicePromptAllOf
from cvg_sdk.model.number_prompt import NumberPrompt
from cvg_sdk.model.prompt_type import PromptType
from cvg_sdk.model.synonyms import Synonyms
globals()['MultipleChoicePrompt'] = MultipleChoicePrompt
globals()['MultipleChoicePromptAllOf'] = MultipleChoicePromptAllOf
globals()['NumberPrompt'] = NumberPrompt
globals()['PromptType'] = PromptType
globals()['Synonyms'] = Synonyms
from cvg_sdk.model.multiple_choice_prompt import MultipleChoicePrompt


class TestMultipleChoicePrompt(unittest.TestCase):
    """MultipleChoicePrompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMultipleChoicePrompt(self):
        """Test MultipleChoicePrompt"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MultipleChoicePrompt()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Assist API

    With the CVG Assist API you can use live transcriptions of customers to provide in-call agent assistance.  CVG Assist API requires some integration with contact center software to link ACD phone number, dialogID und agentID. The call has to be bridged to the contact center head number of e.g. a hotline plus an extension. The contact center then has to invoke `/assist/accept` with the phone number.  Integration with VIER Engage is available. Ask us if you are interested in integrating other contact center software.  CVG Assist API is part of the VIER Cognitive Voice Gateway.  For more details, see [our documentation](/docs/Essential-Use-Cases.html#agent-assistance).  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cvg_sdk.api_client import ApiClient, Endpoint as _Endpoint
from cvg_sdk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cvg_sdk.model.accept_assist_parameters import AcceptAssistParameters
from cvg_sdk.model.assist_recording_start_parameters import AssistRecordingStartParameters
from cvg_sdk.model.assist_recording_stop_parameters import AssistRecordingStopParameters
from cvg_sdk.model.transcription_start_parameters import TranscriptionStartParameters
from cvg_sdk.model.transcription_stop_parameters import TranscriptionStopParameters


class AssistApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.accept_assist_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [],
                'endpoint_path': '/assist/accept',
                'operation_id': 'accept_assist',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'accept_assist_parameters',
                ],
                'required': [
                    'accept_assist_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'accept_assist_parameters':
                        (AcceptAssistParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'accept_assist_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_recording_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/assist/recording/start',
                'operation_id': 'start_recording',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'assist_recording_start_parameters',
                ],
                'required': [
                    'assist_recording_start_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'assist_recording_start_parameters':
                        (AssistRecordingStartParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'assist_recording_start_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.start_transcription_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/assist/transcription/start',
                'operation_id': 'start_transcription',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'transcription_start_parameters',
                ],
                'required': [
                    'transcription_start_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'transcription_start_parameters':
                        (TranscriptionStartParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'transcription_start_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.stop_recording_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/assist/recording/stop',
                'operation_id': 'stop_recording',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'assist_recording_stop_parameters',
                ],
                'required': [
                    'assist_recording_stop_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'assist_recording_stop_parameters':
                        (AssistRecordingStopParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'assist_recording_stop_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.stop_transcription_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/assist/transcription/stop',
                'operation_id': 'stop_transcription',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'transcription_stop_parameters',
                ],
                'required': [
                    'transcription_stop_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'transcription_stop_parameters':
                        (TranscriptionStopParameters,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'transcription_stop_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def accept_assist(
        self,
        accept_assist_parameters,
        **kwargs
    ):
        """Accept assist  # noqa: E501

        Accept assist for the phone number of a bridge call (head number + extension). Frees the headnumber/extension combination for further use.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.accept_assist(accept_assist_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            accept_assist_parameters (AcceptAssistParameters): Parameters for the accept assist operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['accept_assist_parameters'] = \
            accept_assist_parameters
        return self.accept_assist_endpoint.call_with_http_info(**kwargs)

    def start_recording(
        self,
        assist_recording_start_parameters,
        **kwargs
    ):
        """Start or resume recording of the call  # noqa: E501

        Starts or resumes recording of the call.  IMPORTANT: it is the responsibility of the API user to ensure that recording the participants of the call is legal according to the privacy laws and regulations that apply in the respective country.  Recordings can only be made if this has been explicitly allowed in each layer of the hierarchy (reseller, customer, account, project). They are stored for the duration specified in the project settings.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_recording(assist_recording_start_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            assist_recording_start_parameters (AssistRecordingStartParameters): Parameters for the recording start operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['assist_recording_start_parameters'] = \
            assist_recording_start_parameters
        return self.start_recording_endpoint.call_with_http_info(**kwargs)

    def start_transcription(
        self,
        transcription_start_parameters,
        **kwargs
    ):
        """Start transcription  # noqa: E501

        Start transcription for a speaker in a call.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.start_transcription(transcription_start_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            transcription_start_parameters (TranscriptionStartParameters): Parameters for the start transcription operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['transcription_start_parameters'] = \
            transcription_start_parameters
        return self.start_transcription_endpoint.call_with_http_info(**kwargs)

    def stop_recording(
        self,
        assist_recording_stop_parameters,
        **kwargs
    ):
        """Pause or terminate recording of the call  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stop_recording(assist_recording_stop_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            assist_recording_stop_parameters (AssistRecordingStopParameters): Parameters for the recording stop operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['assist_recording_stop_parameters'] = \
            assist_recording_stop_parameters
        return self.stop_recording_endpoint.call_with_http_info(**kwargs)

    def stop_transcription(
        self,
        transcription_stop_parameters,
        **kwargs
    ):
        """Stop transcription  # noqa: E501

        Stop transcription for a speaker in a call.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stop_transcription(transcription_stop_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            transcription_stop_parameters (TranscriptionStopParameters): Parameters for the stop transcription operation

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['transcription_stop_parameters'] = \
            transcription_stop_parameters
        return self.stop_transcription_endpoint.call_with_http_info(**kwargs)




"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cvg_sdk.api_client import ApiClient, Endpoint as _Endpoint
from cvg_sdk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cvg_sdk.model.dialog_phase import DialogPhase
from cvg_sdk.model.recording_objects_response import RecordingObjectsResponse
from cvg_sdk.model.recording_id import RecordingId


class RecordingApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.delete_recording_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/recording/{resellerToken}/{dialogId}',
                'operation_id': 'delete_recording',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                    'phase',
                    'id',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'id',
                ]
            },
            root_map={
                'validations': {
                    ('id',): {
                        'max_length': 50,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                    'phase':
                        (DialogPhase,),
                    'id':
                        (RecordingId,),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                    'phase': 'phase',
                    'id': 'id',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                    'phase': 'query',
                    'id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_recording_artifacts_endpoint = _Endpoint(
            settings={
                'response_type': (RecordingObjectsResponse,),
                'auth': [],
                'endpoint_path': '/recording/{resellerToken}/{dialogId}',
                'operation_id': 'get_recording_artifacts',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                    'phase',
                    'id',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'id',
                ]
            },
            root_map={
                'validations': {
                    ('id',): {
                        'max_length': 50,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                    'phase':
                        (DialogPhase,),
                    'id':
                        (RecordingId,),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                    'phase': 'phase',
                    'id': 'id',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                    'phase': 'query',
                    'id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def delete_recording(
        self,
        reseller_token,
        dialog_id,
        **kwargs
    ):
        """Delete recording  # noqa: E501

        Deletes recording artifacts for the dialog.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_recording(reseller_token, dialog_id, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):

        Keyword Args:
            phase (DialogPhase): Omitting the phase will select the bot dialog. [optional]
            id (RecordingId): Omitting the recording ID will select the default recording of the selected phase.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        return self.delete_recording_endpoint.call_with_http_info(**kwargs)

    def get_recording_artifacts(
        self,
        reseller_token,
        dialog_id,
        **kwargs
    ):
        """Get download URLs for recording  # noqa: E501

        Retrieves recording artifacts for the dialog. Recordings are generally not immediately available after a dialog ends. The bot will receive a notification (see Bot API for endpoint details) once the recording has been processed and is available using this API.  Once the recordings are downloaded you can use the `DELETE` verb on this endpoint to remove the recording, otherwise the recording will be stored until the retention period configured on the project expires.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_recording_artifacts(reseller_token, dialog_id, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):

        Keyword Args:
            phase (DialogPhase): Omitting the phase will select the bot dialog. [optional]
            id (RecordingId): Omitting the recording ID will select the default recording of the selected phase.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            RecordingObjectsResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        return self.get_recording_artifacts_endpoint.call_with_http_info(**kwargs)




"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.audio import Audio
from cvg_sdk.model.dtmf import Dtmf
from cvg_sdk.model.dtmf_all_of import DtmfAllOf
from cvg_sdk.model.speaker import Speaker
from cvg_sdk.model.text import Text
from cvg_sdk.model.transcript_entry import TranscriptEntry
from cvg_sdk.model.voice import Voice
globals()['Audio'] = Audio
globals()['Dtmf'] = Dtmf
globals()['DtmfAllOf'] = DtmfAllOf
globals()['Speaker'] = Speaker
globals()['Text'] = Text
globals()['TranscriptEntry'] = TranscriptEntry
globals()['Voice'] = Voice
from cvg_sdk.model.dtmf import Dtmf


class TestDtmf(unittest.TestCase):
    """Dtmf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDtmf(self):
        """Test Dtmf"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Dtmf()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.recording_api import RecordingApi  # noqa: E501


class TestRecordingApi(unittest.TestCase):
    """RecordingApi unit test stubs"""

    def setUp(self):
        self.api = RecordingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_recording(self):
        """Test case for delete_recording

        Delete recording  # noqa: E501
        """
        pass

    def test_get_recording_artifacts(self):
        """Test case for get_recording_artifacts

        Get download URLs for recording  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cvg_sdk.api_client import ApiClient, Endpoint as _Endpoint
from cvg_sdk.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from cvg_sdk.model.custom import Custom
from cvg_sdk.model.dialog import Dialog
from cvg_sdk.model.dialog_data_parameters import DialogDataParameters
from cvg_sdk.model.entry_type import EntryType
from cvg_sdk.model.external_call_id import ExternalCallId


class DialogApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.attach_custom_data_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/dialog/{resellerToken}/{dialogId}/data',
                'operation_id': 'attach_custom_data',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                    'dialog_data_parameters',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                    'dialog_data_parameters',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                    'dialog_data_parameters':
                        (DialogDataParameters,),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                    'dialog_data_parameters': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_dialog_endpoint = _Endpoint(
            settings={
                'response_type': None,
                'auth': [],
                'endpoint_path': '/dialog/{resellerToken}/{dialogId}',
                'operation_id': 'delete_dialog',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_dialog_endpoint = _Endpoint(
            settings={
                'response_type': (Dialog,),
                'auth': [],
                'endpoint_path': '/dialog/{resellerToken}/{dialogId}',
                'operation_id': 'get_dialog',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                    'include_type',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                    'include_type':
                        ([EntryType],),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                    'include_type': 'includeType',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                    'include_type': 'query',
                },
                'collection_format_map': {
                    'include_type': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_dialog_by_external_call_id_endpoint = _Endpoint(
            settings={
                'response_type': (Dialog,),
                'auth': [],
                'endpoint_path': '/dialog/{resellerToken}/external/{projectToken}/{callId}',
                'operation_id': 'get_dialog_by_external_call_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'project_token',
                    'call_id',
                    'include_type',
                ],
                'required': [
                    'reseller_token',
                    'project_token',
                    'call_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'call_id',
                ]
            },
            root_map={
                'validations': {
                    ('call_id',): {
                        'max_length': 50,
                        'min_length': 1,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'project_token':
                        (str,),
                    'call_id':
                        (ExternalCallId,),
                    'include_type':
                        ([EntryType],),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'project_token': 'projectToken',
                    'call_id': 'callId',
                    'include_type': 'includeType',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'project_token': 'path',
                    'call_id': 'path',
                    'include_type': 'query',
                },
                'collection_format_map': {
                    'include_type': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_single_entry_endpoint = _Endpoint(
            settings={
                'response_type': (Custom,),
                'auth': [],
                'endpoint_path': '/dialog/{resellerToken}/{dialogId}/custom/{key}',
                'operation_id': 'get_single_entry',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'reseller_token',
                    'dialog_id',
                    'key',
                ],
                'required': [
                    'reseller_token',
                    'dialog_id',
                    'key',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'reseller_token':
                        (str,),
                    'dialog_id':
                        (str,),
                    'key':
                        (str,),
                },
                'attribute_map': {
                    'reseller_token': 'resellerToken',
                    'dialog_id': 'dialogId',
                    'key': 'key',
                },
                'location_map': {
                    'reseller_token': 'path',
                    'dialog_id': 'path',
                    'key': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def attach_custom_data(
        self,
        reseller_token,
        dialog_id,
        dialog_data_parameters,
        **kwargs
    ):
        """Attach custom data to a dialog  # noqa: E501

        Attach custom data to a dialog  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.attach_custom_data(reseller_token, dialog_id, dialog_data_parameters, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):
            dialog_data_parameters (DialogDataParameters):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        kwargs['dialog_data_parameters'] = \
            dialog_data_parameters
        return self.attach_custom_data_endpoint.call_with_http_info(**kwargs)

    def delete_dialog(
        self,
        reseller_token,
        dialog_id,
        **kwargs
    ):
        """Delete dialog by dialog ID  # noqa: E501

        Delete data of a dialog by dialog ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_dialog(reseller_token, dialog_id, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            None
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        return self.delete_dialog_endpoint.call_with_http_info(**kwargs)

    def get_dialog(
        self,
        reseller_token,
        dialog_id,
        **kwargs
    ):
        """Get dialog by dialog ID  # noqa: E501

        Get data of a dialog by dialog ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_dialog(reseller_token, dialog_id, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):

        Keyword Args:
            include_type ([EntryType]): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Dialog
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        return self.get_dialog_endpoint.call_with_http_info(**kwargs)

    def get_dialog_by_external_call_id(
        self,
        reseller_token,
        project_token,
        call_id,
        **kwargs
    ):
        """Get dialog by external call ID  # noqa: E501

        Get data of a dialog by external call ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_dialog_by_external_call_id(reseller_token, project_token, call_id, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            project_token (str):
            call_id (ExternalCallId):

        Keyword Args:
            include_type ([EntryType]): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Dialog
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['project_token'] = \
            project_token
        kwargs['call_id'] = \
            call_id
        return self.get_dialog_by_external_call_id_endpoint.call_with_http_info(**kwargs)

    def get_single_entry(
        self,
        reseller_token,
        dialog_id,
        key,
        **kwargs
    ):
        """Get a single custom dialog data entry  # noqa: E501

        Get a single custom dialog data entry. If the key exists more than once, only the newest entry will be returned.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_single_entry(reseller_token, dialog_id, key, async_req=True)
        >>> result = thread.get()

        Args:
            reseller_token (str):
            dialog_id (str):
            key (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            Custom
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['reseller_token'] = \
            reseller_token
        kwargs['dialog_id'] = \
            dialog_id
        kwargs['key'] = \
            key
        return self.get_single_entry_endpoint.call_with_http_info(**kwargs)




from setuptools import setup, find_packages  # noqa: H301

setup(
    name="cvg-python-sdk",
    version="0.5.1",
    description="VIER Cognitive Voice Gateway SDK",
    author="VIER GmbH",
    author_email="support@vier.ai",
    url="https://cognitivevoice.io",
    keywords=["OpenAPI", "OpenAPI-Generator", "VIER", "VIER Cognitive Voice Gateway SDK"],
    python_requires=">=3.6",
    install_requires=[
        'python_dateutil >= 2.5.3',
        'urllib3 >= 1.25.3',
    ],
    packages=find_packages(exclude=["test", "tests"]),
    package_data={'': ['requirements.txt']},
    include_package_data=True,
    license="MIT",
)



"""
    VIER Cognitive Voice Dialog API

    CVG dialog history  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.answer import Answer
from cvg_sdk.model.bridge import Bridge
from cvg_sdk.model.custom import Custom
from cvg_sdk.model.end import End
from cvg_sdk.model.entry import Entry
from cvg_sdk.model.entry_type import EntryType
from cvg_sdk.model.forward import Forward
from cvg_sdk.model.inactivity import Inactivity
from cvg_sdk.model.playback import Playback
from cvg_sdk.model.prompt import Prompt
from cvg_sdk.model.prompt_all_of import PromptAllOf
from cvg_sdk.model.prompt_type import PromptType
from cvg_sdk.model.recording_start import RecordingStart
from cvg_sdk.model.recording_stop import RecordingStop
from cvg_sdk.model.start import Start
from cvg_sdk.model.synthesis import Synthesis
from cvg_sdk.model.tone import Tone
from cvg_sdk.model.transcription import Transcription
globals()['Answer'] = Answer
globals()['Bridge'] = Bridge
globals()['Custom'] = Custom
globals()['End'] = End
globals()['Entry'] = Entry
globals()['EntryType'] = EntryType
globals()['Forward'] = Forward
globals()['Inactivity'] = Inactivity
globals()['Playback'] = Playback
globals()['Prompt'] = Prompt
globals()['PromptAllOf'] = PromptAllOf
globals()['PromptType'] = PromptType
globals()['RecordingStart'] = RecordingStart
globals()['RecordingStop'] = RecordingStop
globals()['Start'] = Start
globals()['Synthesis'] = Synthesis
globals()['Tone'] = Tone
globals()['Transcription'] = Transcription
from cvg_sdk.model.prompt import Prompt


class TestPrompt(unittest.TestCase):
    """Prompt unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPrompt(self):
        """Test Prompt"""
        # FIXME: construct object with mandatory attributes with example values
        # model = Prompt()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Health API

    CVG health  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import unittest

import cvg_sdk
from cvg_sdk.api.health_api import HealthApi  # noqa: E501


class TestHealthApi(unittest.TestCase):
    """HealthApi unit test stubs"""

    def setUp(self):
        self.api = HealthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_project_health(self):
        """Test case for get_project_health

        Get the health status of a project based on calls within a time range (by default the last 10 minutes). NOTE: this API is still experimental and subject to change.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    VIER Cognitive Voice Call API

    With the VIER Cognitive Voice Call API you can easily do things like building your voicebots, which can be reached via phone calls. You can receive speech input of the customer as transcripted text in many languages. Let different voices say your text in this call. After the voicebot dialog you may drop the call (call fully completed by bot) or transfer the call e.g. to the relevant service hotline (human agent required to satisfy customer).  On some events, such as receiving an incoming phone call or transcription of a customer's utterance, VIER makes an HTTP request to a URL to be provided by you. This is called a webhook. To handle a webhook, you need to build a small web application that can accept the HTTP requests. The required webhooks are listed as bot endpoints.  The operations defined in this specification can be used by your bot to trigger certain voice and/or telephony related actions on the currently active call.  Most of the available operations are subject to queuing, meaning that the commands, even when triggered simultaneously, will not be executed simultaneously. Instead, these operations will be executed after each other. This is being done to simplify bot development as otherwise the bot would need to hit exact timings for the operations it triggers to not produce overlapping audio in the phone and still be quick enough to feel responsive to the conversation partner.  The queuing mechanism allows the bot to simply trigger several operations after each other and CVG makes sure to to execute them without overlap after each other. Some operations also support a `bargeIn` flag, which makes the operation interruptible by the conversation partner.  All operations that are not subject to queuing will document this fact in their respective description.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from cvg_sdk.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from cvg_sdk.exceptions import ApiAttributeError


def lazy_import():
    from cvg_sdk.model.barge_in_options_one_of import BargeInOptionsOneOf
    globals()['BargeInOptionsOneOf'] = BargeInOptionsOneOf


class BargeInOptions(ModelComposed):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
    }

    validations = {
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        lazy_import()
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        lazy_import()
        return {
            'on_speech': (bool,),  # noqa: E501
            'on_dtmf': (bool,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'on_speech': 'onSpeech',  # noqa: E501
        'on_dtmf': 'onDtmf',  # noqa: E501
    }

    read_only_vars = {
    }

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, *args, **kwargs):  # noqa: E501
        """BargeInOptions - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            on_speech (bool): [optional]  # noqa: E501
            on_dtmf (bool): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)

        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
        '_composed_instances',
        '_var_name_to_model_instances',
        '_additional_properties_model_instances',
    ])

    @convert_js_args_to_python_args
    def __init__(self, *args, **kwargs):  # noqa: E501
        """BargeInOptions - a model defined in OpenAPI

        Keyword Args:
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
            on_speech (bool): [optional]  # noqa: E501
            on_dtmf (bool): [optional]  # noqa: E501
        """

        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        constant_args = {
            '_check_type': _check_type,
            '_path_to_item': _path_to_item,
            '_spec_property_naming': _spec_property_naming,
            '_configuration': _configuration,
            '_visited_composed_classes': self._visited_composed_classes,
        }
        composed_info = validate_get_composed_info(
            constant_args, kwargs, self)
        self._composed_instances = composed_info[0]
        self._var_name_to_model_instances = composed_info[1]
        self._additional_properties_model_instances = composed_info[2]
        discarded_args = composed_info[3]

        for var_name, var_value in kwargs.items():
            if var_name in discarded_args and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self._additional_properties_model_instances:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")

    @cached_property
    def _composed_schemas():
        # we need this here to make our import statements work
        # we must store _composed_schemas in here so the code is only run
        # when we invoke this method. If we kept this at the class
        # level we would get an error because the class level
        # code would be run when this module is imported, and these composed
        # classes don't exist yet because their module has not finished
        # loading
        lazy_import()
        return {
          'anyOf': [
          ],
          'allOf': [
          ],
          'oneOf': [
              BargeInOptionsOneOf,
              bool,
          ],
        }



"""
    VIER Cognitive Voice Recording API

    With the Recording API, client applications can manage recordings that have previously been created using the Call or Assist APIs.  # noqa: E501

    The version of the OpenAPI document: 1.24.4
    Contact: support@vier.ai
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cvg_sdk
from cvg_sdk.model.dialog_phase import DialogPhase


class TestDialogPhase(unittest.TestCase):
    """DialogPhase unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testDialogPhase(self):
        """Test DialogPhase"""
        # FIXME: construct object with mandatory attributes with example values
        # model = DialogPhase()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
